#
# spec file for package python-libtmux
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-libtmux
Version:        0.40.1
Release:        1.1
Summary:        Python API / wrapper for tmux
License:        MIT
URL:            https://github.com/tmux-python/libtmux/
Source:         https://github.com/tmux-python/libtmux/archive/v%{version}.tar.gz#/libtmux-%{version}.tar.gz
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test
# https://github.com/tmux-python/libtmux/blob/master/pyproject.toml#L68
BuildRequires:  %{python_module gp-libs >= 0.0.4}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest-rerunfailures}
BuildRequires:  %{python_module pytest}
# we do not need pytest-watcher for building on OBS
BuildRequires:  tmux
# /SECTION
BuildArch:      noarch
%python_subpackages

%description
libtmux is a typed python scripting library for tmux. You can use it to command and control tmux servers, sessions, windows, and panes. It is the tool powering tmuxp, a tmux workspace manager.

%prep
%setup -q -n libtmux-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Move src to a different path to do not use in tests
mv src src.bak
# Tests fail unless src/libtmux/__about__.py exists...
mkdir -p src/libtmux/
cp src.bak/libtmux/__about__.py src/libtmux/

export TMUX_TMPDIR=/tmp
echo "Starting tests with PYTEST_IGNORE set to $PYTEST_IGNORE"
export PYTEST_IGNORE="test_select_window or test_session.py::test_select_window or tests/test_session.py::test_select_window or tests/legacy_api/test_session.py::test_select_window or test_function_times_out"
%pytest -k "not (${PYTEST_IGNORE})"

rm -rf src/
mv src.bak src

%files %{python_files}
%{python_sitelib}/libtmux/
%{python_sitelib}/libtmux-%{version}*-info
%doc README.md
%license LICENSE

%changelog
* Fri Dec 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.40.1:
  * Bug fixes
  - Fix passing both window command and environment by
    @ppentchev in #553
* Sat Dec 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.40.0:
  * Python 3.9 Modernization by @tony in #550
  * test(legacy[session]) Stabilize assertion by @tony in #552
* Wed Nov 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.39.0:
  * Drop Python 3.8 by @tony in #548
    Python 3.8 reached end-of-life on October 7th, 2024 (see
    devguide.python.org, Status of Python Versions, Unsupported
    versions
    See also:
    https://devguide.python.org/versions/#unsupported-versions
* Wed Nov 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.38.1:
  * Minimum Python back to 3.8 for now.
* Wed Nov 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.38.0:
  * Development
  - Project and package management: poetry to uv (#547)
    uv is the new package and project manager for the project,
    replacing Poetry.
  - Code quality: Use f-strings in more places (#540)
    via ruff 0.4.2.
  * Documentation
  - [docs] Sphinx v8 compatibility: configure a non-empty
    inventory name for Python Intersphinx mapping. by @jayaddison
    in #542
  - Fix docstrings in query_list for MultipleObjectsReturned and
    ObjectDoesNotExist.
  * Other
  - Bump dev dependencies, including ruff 0.4.2, f-string tweaks
    by @tony in #540
* Tue Apr 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.37.0:
  Tests
  * pytest-xdist support in #522
  * test stability improvements in #522
  - retry_until() tests: Relax clock in assert.
  - tests/test_pane.py::test_capture_pane_start: Use
    retry_until() to poll, improve correctness of test.
* Sun Mar 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.36.0:
  * Linting: Aggressive ruff pass (ruff v0.3.4) by @tony in #539
* Sun Mar 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.35.1:
  * fix: server.attached_sessions by @patrislav1 in #537
  * chore(Server.attached_sessions): Use .filter() by @tony in #538
* Tue Mar 19 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.35.0:
  Breaking changes
  * refactor: Eliminate redundant targets / window_index's across
    codebase by @tony in #536
* Sun Mar 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.34.0:
  Breaking changes!
  * Command target change (#535)#
    Commands: All cmd() methods using custom or overridden targets
    must use the keyword argument target. This avoids entanglement
    with inner shell values that include -t for other purposes.
    These methods include:
  - Server.cmd()
  - Session.cmd()
  - Window.cmd()
  - Pane.cmd()
* Sun Mar 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.33.0:
  Breaking changes!
  * Improved new sessions (#532)
  - Session.new_window():
  - Learned direction, via WindowDirection).
  - PEP 3102 keyword-only arguments after window name (#534).
  - Added {meth}Window.new_window() shorthand to create window
    based on that window's position.
  * Improved window splitting (#532)
  - Window.split_window() to Window.split()
  - Deprecate Window.split_window()
  - Pane.split_window() to Pane.split()
  - Deprecate Pane.split_window()
  - Learned direction, via PaneDirection).
  - Deprecate vertical and horizontal in favor of direction.
  - Learned zoom
  * Tweak: Pane position (#532)
    It's now possible to retrieve the position of a pane in a
    window via a bool helper::
  - Pane.at_left
  - Pane.at_right
  - Pane.at_bottom
  - Pane.at_right
* Sat Mar 16 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.32.0:
  * Fix docstring ordering in pane.split_window by @Ngalstyan4
    in #528
  * Add implicit exports into init.py by @ssbarnea in #531
* Sun Feb 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.31.0:
  * Cleanups (#527)
  - Streamline {Server,Session,Window,Pane}.cmd(), across all
    usages to:
  - Use cmd: str as first positional
  - Removed unused keyword arguments **kwargs
  * Renamings (#527)
  - Session.attached_window renamed to Session.active_window()
  - Session.attached_window deprecated
  - Session.attached_pane renamed to Session.active_pane()
  - Session.attached_pane deprecated
  - Window.attached_pane renamed to Window.active_pane()
  - Window.attached_pane deprecated
  * Improvements (#527)
  - Server.attached_windows now users QueryList’s .filter()
* Sun Feb 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.30.2:
  * Bump `TMUX_MAX_VERSION` 3.3 -> 3.4
* Sun Feb 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.30.1:
  * pytest plugin, test module: Update to renamed methods
    introduced in v0.30.0
* Sun Feb 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.30.0:
  * New commands
  - Pane.kill()
  * Renamed commands
  - Window.select_window() renamed to Window.select()
  - Deprecated Window.select_window()
  - Pane.select_pane() renamed to Pane.select()
  - Deprecated Pane.pane_select()
  - Session.attach_session() renamed to Session.attach()
  - Deprecated Session.attach_session()
  - Server.kill_server() renamed to Server.kill()
  - Deprecated Server.kill_server()
  - Session.kill_session() renamed to Session.kill()
  - Deprecated Session.kill_session()
  - Window.kill_window() renamed to Window.kill()
    Deprecated Window.kill_window()
  * Improved commands
  - Server.new_session(): Support environment variables
  - Window.split_window(): Support size via -l
  - Supports columns/rows (size=10) and percentage (size='10%%')
* Sun Feb 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.29.0:
  * fix(warnings): Use |DeprecationWarning| for APIs being
    deprecated
  * pytest: Ignore |DeprecationWarning| in tests
* Sun Feb 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.28.1:
  Maintenance only, no bug fixes or new features
* Thu Feb 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.28.0:
  * Breaking changes
  - Session.new_window() + Window.split_window(): No longer
    attaches by default
  - 0.28 +: Now defaults to attach=False.
  - 0.27.1 and before: defaults to attach=True.
    Pass attach=True for the old behavior.
  - Pane.resize_pane() renamed to Pane.resize(): (#523)
    This convention will be more consistent with Window.resize().
  - Pane.resize_pane(): Params changed (#523)
    No longer accepts -U, -D, -L, -R directly, instead accepts
    ResizeAdjustmentDirection.
  * New features
  - Pane.resize(): Improved param coverage (#523)
    Learned to accept adjustments via adjustment_direction w/
    ResizeAdjustmentDirection + adjustment.
    Learned to accept manual height and / or width (columns/rows
    or percentage) Zoom (and unzoom)
  - Window.resize_window(): New Method (#523)
    If Pane.resize_pane() (now Pane.resize()) didn't work before,
    try resizing the window.
  * Bug fixes
  - Window.refresh() and Pane.refresh(): Refresh more underlying
    state (#523)
  - Obj._refresh: Allow passing args (#523)
    e.g. -a (all) to list-panes and list-windows
  - Server.panes: Fix listing of panes (#523)
    Would list only panes in attached session, rather than all in
    a server.
  * Improvements
  - Pane, Window: Improve parsing of option values that return
    numbers
    (#520)
  - Obj._refresh: Allow passing list_extra_args to ensure
    list-windows and list-panes can return more than the target
    (#523)
* Fri Feb  9 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- ignore some checks again, that seemed fine but are now again
  failing intermittently
* Thu Feb  8 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.27.1:
  * pyproject: Include MIGRATION in sdist by @tony in #517, for
    [#508]
* Thu Feb  8 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.27.0:
  * Improvements
  - QueryList: Generic fixes by @tony in #515
  - This improves the annotations in descendant objects such
    as:
  - Server.sessions
  - Session.windows
  - Window.panes
  - Bolster tests (ported from libvcs): doctests and pytests
* Thu Feb  8 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.26.0:
  * Breaking change
  - get_by_id() (already deprecated) keyword argument renamed
    from id to
  - Server.get_by_id(session_id), Session.get_by_id(window_id),
    and Window.get_by_id(pane_id) (#514)
  * Documentation
  - Various docstring fixes and tweaks (#514)
  * Development
  - Strengthen linting (#514)
  - Add flake8-commas (COM)
  - Add flake8-builtins (A)
  - Add flake8-errmsg (EM)
  * CI
  - Move CodeQL from advanced configuration file to GitHub's
    default
* Mon Nov 27 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.25.0:
  * Comparator fixes
  - Fixed __eq__ for windows. by @m1guelperez in #505
  - fix(pane,session,server): Return False if type mismatched by
    @tony in #510
  * Documentation
  - ruff: Enable pydocstyle w/ numpy convention by @tony in #509
* Fri Nov 24 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.24.1:
  * packaging: Remove requirements/ folder. Unused. by @tony in
    [#507]
  * pyproject: Add gp-libs to test dependency group
* Mon Nov 20 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.24.0:
  * Breaking changes
  - Drop Python 3.7 by @tony in #497
  * Packaging
  - packaging(pytest): Move configuration to pyproject.toml by
    @tony in #499
  - Poetry: 1.5.1 -> 1.6.1 (#497), 1.6.1 -> 1.7.0 (direct to
    trunk)
    See also:
    https://github.com/python-poetry/poetry/blob/1.7.0/CHANGELOG.md
  - Packaging (poetry): Fix development dependencies
    Per Poetry's docs on managing dependencies and poetry check,
    we had it wrong:
    Instead of using extras, we should create these:
    [tool.poetry.group.group-name.dependencies]
    dev-dependency = "1.0.0"
    Which we now do.
  * Development
  - Formatting: black -> ruff format by @tony in #506
  - CI: Update action packages to fix warnings
  - dorny/paths-filter: 2.7.0 -> 2.11.1
  - codecov/codecov-action: 2 -> 3
  * Full Changelog: v0.23.2...v0.24.0
* Mon Sep 11 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.23.2:
  _Maintenance only, no bug fixes or new features_
  Final Python 3.7 Release (End of life was June 27th, 2023)
* Wed Sep  6 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.23.1:
  _Maintenance only, no bug fixes, or new features_
  * Development
  - Automated typo fixes from [typos-cli]:
    ```console
    typos --format brief --write-changes
    ```
    [typos-cli]: https://github.com/crate-ci/typos
  - ruff's linter for code comments, `ERA` (eradicate), has been
    removed
* Wed Sep  6 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.23.0:
  _This maintenance release covers only developer quality of life
  improvements, no bug fixes or new features_
  * Maintenance
  - Stricter code quality rules (via ruff) by @tony in
    https://github.com/tmux-python/libtmux/pull/488
* Wed Sep  6 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.22.2:
  _Maintenance only, no bug fixes or features for this release_
  * Build system
  - ci: Remove setuptools requirement for build-system in
    https://github.com/tmux-python/libtmux/pull/495
* Mon May 29 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.22.1:
  * Add back black dev dependency until `ruff` replaces black's
    formatting
* Sat May 27 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.22.0:
  * Move formatting, import sorting, and linting to ruff.
  * This rust-based checker has dramatically improved performance.
    Linting and formatting can be done almost instantly.
  * This change replaces black, isort, flake8 and flake8 plugins.
* Tue May 16 2023 Johannes Kastl <kastl@b1-systems.de>
- ignore flaky test test_capture_pane (see
  https://github.com/tmux-python/libtmux/issues/484)
- ignore flaky test test_new_window_with_environment[environment0]
  (see https://github.com/tmux-python/libtmux/
  issues/480#issuecomment-1551533987)
* Mon May  8 2023 Daniel Garcia <daniel.garcia@suse.com>
- Depends on poetry-core for building, we don't need the full poetry
  module in this case.
* Fri May  5 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Thu Apr  6 2023 Johannes Kastl <kastl@b1-systems.de>
- ignore yet another test:
  test_new_window_with_environment[environment1]
  (reported at https://github.com/tmux-python/libtmux/issues/478)
* Thu Mar  9 2023 Johannes Kastl <kastl@b1-systems.de>
- new package python-libtmux: Python API / wrapper for tmux
